import setuptools

setuptools.setup(
    name="NightWindGameLib",
    version="0.0.4",
    author="Nova_NightWind0311",
    author_email="",
    descripiton="Some little games",
    long_escription_content_type="text/markdown",
    url="https://github.com/",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
